@@ -20,14 +20,21 @@
  ==============================================================================
  */
 
-#include "PluginProcessor.h"
 #include "PluginEditor.h"
+#include "PluginProcessor.h"
 
 //==============================================================================
-ProbeDecoderAudioProcessorEditor::ProbeDecoderAudioProcessorEditor (ProbeDecoderAudioProcessor& p, juce::AudioProcessorValueTreeState& vts)
-: juce::AudioProcessorEditor (&p), footer (p.getOSCParameterInterface()), processor (p), valueTreeState(vts),
-probe(*valueTreeState.getParameter("azimuth"), valueTreeState.getParameterRange("azimuth"),
-      *valueTreeState.getParameter("elevation"), valueTreeState.getParameterRange("elevation"))
+ProbeDecoderAudioProcessorEditor::ProbeDecoderAudioProcessorEditor (
+    ProbeDecoderAudioProcessor& p,
+    juce::AudioProcessorValueTreeState& vts) :
+    juce::AudioProcessorEditor (&p),
+    footer (p.getOSCParameterInterface()),
+    processor (p),
+    valueTreeState (vts),
+    probe (*valueTreeState.getParameter ("azimuth"),
+           valueTreeState.getParameterRange ("azimuth"),
+           *valueTreeState.getParameter ("elevation"),
+           valueTreeState.getParameterRange ("elevation"))
 {
     // Make sure that before the constructor has finished, you've set the
     // editor's size to whatever you need it to be.
@@ -35,72 +42,76 @@ probe(*valueTreeState.getParameter("azimuth"), valueTreeState.getParameterRange(
     setLookAndFeel (&globalLaF);
 
     // ==== SPHERE AND ELEMENTS ===============
-    addAndMakeVisible(&sphere);
+    addAndMakeVisible (&sphere);
     //sphere.addListener(this);
 
-    probe.setColour(juce::Colours::aqua);
-    sphere.addElement(&probe);
-
+    probe.setColour (juce::Colours::aqua);
+    sphere.addElement (&probe);
 
     // ======================================
 
+    addAndMakeVisible (&title);
+    title.setTitle (juce::String ("Probe"), juce::String ("Decoder"));
+    title.setFont (globalLaF.robotoBold, globalLaF.robotoLight);
 
-    addAndMakeVisible(&title);
-    title.setTitle(juce::String("Probe"),juce::String("Decoder"));
-    title.setFont(globalLaF.robotoBold,globalLaF.robotoLight);
-
-    addAndMakeVisible(&footer);
+    addAndMakeVisible (&footer);
 
     toolTipWin.setLookAndFeel (&globalLaF);
-    toolTipWin.setMillisecondsBeforeTipAppears(500);
+    toolTipWin.setMillisecondsBeforeTipAppears (500);
     toolTipWin.setOpaque (false);
 
-
-    cbNormalizationAtachement.reset (new ComboBoxAttachment (valueTreeState,"useSN3D", *title.getInputWidgetPtr()->getNormCbPointer()));
-    cbOrderAtachement.reset (new ComboBoxAttachment (valueTreeState,"orderSetting", *title.getInputWidgetPtr()->getOrderCbPointer()));
-
+    cbNormalizationAtachement.reset (
+        new ComboBoxAttachment (valueTreeState,
+                                "useSN3D",
+                                *title.getInputWidgetPtr()->getNormCbPointer()));
+    cbOrderAtachement.reset (
+        new ComboBoxAttachment (valueTreeState,
+                                "orderSetting",
+                                *title.getInputWidgetPtr()->getOrderCbPointer()));
 
     // ======================== YAW PITCH ROLL GROUP
-    ypGroup.setText("Azimuth & Elevation");
+    ypGroup.setText ("Azimuth & Elevation");
     ypGroup.setTextLabelPosition (juce::Justification::centredLeft);
     ypGroup.setColour (juce::GroupComponent::outlineColourId, globalLaF.ClSeperator);
     ypGroup.setColour (juce::GroupComponent::textColourId, juce::Colours::white);
-    addAndMakeVisible(&ypGroup);
-    ypGroup.setVisible(true);
+    addAndMakeVisible (&ypGroup);
+    ypGroup.setVisible (true);
 
-    addAndMakeVisible(&slAzimuth);
-    slAzimuthAttachment.reset (new SliderAttachment (valueTreeState,"azimuth", slAzimuth));
+    addAndMakeVisible (&slAzimuth);
+    slAzimuthAttachment.reset (new SliderAttachment (valueTreeState, "azimuth", slAzimuth));
     slAzimuth.setSliderStyle (juce::Slider::RotaryHorizontalVerticalDrag);
     slAzimuth.setTextBoxStyle (juce::Slider::TextBoxBelow, false, 50, 15);
-    slAzimuth.setReverse(true);
+    slAzimuth.setReverse (true);
     slAzimuth.setColour (juce::Slider::rotarySliderOutlineColourId, globalLaF.ClWidgetColours[0]);
-    slAzimuth.setRotaryParameters(juce::MathConstants<float>::pi, 3 * juce::MathConstants<float>::pi, false);
-    slAzimuth.setTooltip("Azimuth angle");
-    slAzimuth.setTextValueSuffix(juce::CharPointer_UTF8 (R"(°)"));
+    slAzimuth.setRotaryParameters (juce::MathConstants<float>::pi,
+                                   3 * juce::MathConstants<float>::pi,
+                                   false);
+    slAzimuth.setTooltip ("Azimuth angle");
+    slAzimuth.setTextValueSuffix (juce::CharPointer_UTF8 (R"(°)"));
 
-    addAndMakeVisible(&slElevation);
-    slElevationAttachment.reset (new SliderAttachment (valueTreeState,"elevation", slElevation));
+    addAndMakeVisible (&slElevation);
+    slElevationAttachment.reset (new SliderAttachment (valueTreeState, "elevation", slElevation));
     slElevation.setSliderStyle (juce::Slider::RotaryHorizontalVerticalDrag);
     slElevation.setTextBoxStyle (juce::Slider::TextBoxBelow, false, 50, 15);
     slElevation.setColour (juce::Slider::rotarySliderOutlineColourId, globalLaF.ClWidgetColours[1]);
-    slElevation.setRotaryParameters(0.5 * juce::MathConstants<float>::pi, 2.5 * juce::MathConstants<float>::pi, false);
-    slElevation.setTooltip("Elevation angle");
-
+    slElevation.setRotaryParameters (0.5 * juce::MathConstants<float>::pi,
+                                     2.5 * juce::MathConstants<float>::pi,
+                                     false);
+    slElevation.setTooltip ("Elevation angle");
 
     // ================ LABELS ===================
-    addAndMakeVisible(&lbAzimuth);
-    lbAzimuth.setText("Azimuth");
+    addAndMakeVisible (&lbAzimuth);
+    lbAzimuth.setText ("Azimuth");
 
-    addAndMakeVisible(&lbElevation);
-    lbElevation.setText("Elevation");
+    addAndMakeVisible (&lbElevation);
+    lbElevation.setText ("Elevation");
 
     startTimer (20);
 }
 
-
 ProbeDecoderAudioProcessorEditor::~ProbeDecoderAudioProcessorEditor()
 {
-    setLookAndFeel(nullptr);
+    setLookAndFeel (nullptr);
 }
 
 //==============================================================================
@@ -124,26 +135,25 @@ void ProbeDecoderAudioProcessorEditor::timerCallback()
 
 void ProbeDecoderAudioProcessorEditor::resized()
 {
-
     const int leftRightMargin = 30;
     const int headerHeight = 60;
     const int footerHeight = 25;
     juce::Rectangle<int> area (getLocalBounds());
 
     juce::Rectangle<int> footerArea (area.removeFromBottom (footerHeight));
-    footer.setBounds(footerArea);
+    footer.setBounds (footerArea);
 
-    area.removeFromLeft(leftRightMargin);
-    area.removeFromRight(leftRightMargin);
-    juce::Rectangle<int> headerArea = area.removeFromTop    (headerHeight);
+    area.removeFromLeft (leftRightMargin);
+    area.removeFromRight (leftRightMargin);
+    juce::Rectangle<int> headerArea = area.removeFromTop (headerHeight);
     title.setBounds (headerArea);
-    area.removeFromTop(10);
+    area.removeFromTop (10);
 
     juce::Rectangle<int> sliderRow;
 
     // ============== SIDEBAR RIGHT ====================
     // =================================================
-    juce::Rectangle<int> sideBarArea (area.removeFromRight(190));
+    juce::Rectangle<int> sideBarArea (area.removeFromRight (190));
 
     const int rotSliderHeight = 55;
     const int rotSliderSpacing = 10;
@@ -151,28 +161,24 @@ void ProbeDecoderAudioProcessorEditor::resized()
     const int rotSliderWidth = 40;
     const int labelHeight = 15;
 
-
     // -------------- Yaw Pitch Roll ------------------
-    juce::Rectangle<int> yprArea (sideBarArea.removeFromTop(25 + rotSliderHeight + labelHeight));
+    juce::Rectangle<int> yprArea (sideBarArea.removeFromTop (25 + rotSliderHeight + labelHeight));
     ypGroup.setBounds (yprArea);
-    yprArea.removeFromTop(25); //for box headline
+    yprArea.removeFromTop (25); //for box headline
 
-    sliderRow = (yprArea.removeFromTop(rotSliderHeight));
-    slAzimuth.setBounds (sliderRow.removeFromLeft(rotSliderWidth));
-    sliderRow.removeFromLeft(rotSliderSpacing);
-    slElevation.setBounds (sliderRow.removeFromLeft(rotSliderWidth));
+    sliderRow = (yprArea.removeFromTop (rotSliderHeight));
+    slAzimuth.setBounds (sliderRow.removeFromLeft (rotSliderWidth));
+    sliderRow.removeFromLeft (rotSliderSpacing);
+    slElevation.setBounds (sliderRow.removeFromLeft (rotSliderWidth));
 
-    lbAzimuth.setBounds(yprArea.removeFromLeft(rotSliderWidth));
-    yprArea.removeFromLeft(rotSliderSpacing - 5);
-    lbElevation.setBounds(yprArea.removeFromLeft(rotSliderWidth + 10));
-
-    sideBarArea.removeFromTop(20);
+    lbAzimuth.setBounds (yprArea.removeFromLeft (rotSliderWidth));
+    yprArea.removeFromLeft (rotSliderSpacing - 5);
+    lbElevation.setBounds (yprArea.removeFromLeft (rotSliderWidth + 10));
 
+    sideBarArea.removeFromTop (20);
 
     // ============== SIDEBAR LEFT ====================
 
-    area.removeFromRight(10); // spacing
-    sphere.setBounds(area.getX(), area.getY(),area.getWidth()-20,area.getWidth()-20);
-
-
+    area.removeFromRight (10); // spacing
+    sphere.setBounds (area.getX(), area.getY(), area.getWidth() - 20, area.getWidth() - 20);
 }
