@@ -20,54 +20,54 @@
  ==============================================================================
  */
 
-
 #pragma once
 
 #include <JuceHeader.h>
 
+#include "IOHelper.h"
 #include "OSC/OSCInputStream.h"
 #include "OSC/OSCParameterInterface.h"
-#include "IOHelper.h"
 
 typedef std::vector<std::unique_ptr<juce::RangedAudioParameter>> ParameterList;
 
 template <class inputType, class outputType, bool combined = false>
 
-class AudioProcessorBase :  public juce::AudioProcessor,
-                            public OSCMessageInterceptor,
-                            public juce::VSTCallbackHandler,
-                            public IOHelper<inputType, outputType, combined>,
-                            public juce::AudioProcessorValueTreeState::Listener
+class AudioProcessorBase : public juce::AudioProcessor,
+                           public OSCMessageInterceptor,
+                           public juce::VSTCallbackHandler,
+                           public IOHelper<inputType, outputType, combined>,
+                           public juce::AudioProcessorValueTreeState::Listener
 {
 public:
-
-    AudioProcessorBase () : AudioProcessor(),
-                            oscParameterInterface (*this, parameters),
-                            parameters (*this, nullptr, juce::String (JucePlugin_Name), {})
+    AudioProcessorBase() :
+        AudioProcessor(),
+        oscParameterInterface (*this, parameters),
+        parameters (*this, nullptr, juce::String (JucePlugin_Name), {})
     {
-
     }
 
     AudioProcessorBase (ParameterList parameterLayout) :
-                            AudioProcessor(),
-                            parameters (*this, nullptr, juce::String (JucePlugin_Name), {parameterLayout.begin(), parameterLayout.end()}),
-                            oscParameterInterface (*this, parameters)
+        AudioProcessor(),
+        parameters (*this,
+                    nullptr,
+                    juce::String (JucePlugin_Name),
+                    { parameterLayout.begin(), parameterLayout.end() }),
+        oscParameterInterface (*this, parameters)
     {
-
     }
 
     AudioProcessorBase (const BusesProperties& ioLayouts, ParameterList parameterLayout) :
-                            AudioProcessor (ioLayouts),
-                            parameters (*this, nullptr, juce::String (JucePlugin_Name), { parameterLayout.begin(), parameterLayout.end() }),
-                            oscParameterInterface (*this, parameters)
+        AudioProcessor (ioLayouts),
+        parameters (*this,
+                    nullptr,
+                    juce::String (JucePlugin_Name),
+                    { parameterLayout.begin(), parameterLayout.end() }),
+        oscParameterInterface (*this, parameters)
     {
-
     }
 
     ~AudioProcessorBase() override {}
 
-
-
     //======== AudioProcessor stuff  =======================================================
 
 #ifndef JucePlugin_PreferredChannelConfigurations
@@ -78,12 +78,7 @@ public:
     }
 #endif
 
-
-    const juce::String getName() const override
-    {
-        return JucePlugin_Name;
-    }
-
+    const juce::String getName() const override { return JucePlugin_Name; }
 
     bool acceptsMidi() const override
     {
@@ -103,19 +98,18 @@ public:
 #endif
     }
 
-    double getTailLengthSeconds() const override
-    {
-        return 0.0;
-    }
+    double getTailLengthSeconds() const override { return 0.0; }
 
     //======== VSTCallbackHandler =======================================================
-    juce::pointer_sized_int handleVstManufacturerSpecific (juce::int32 index, juce::pointer_sized_int value,
-                                                     void* ptr, float opt) override
+    juce::pointer_sized_int handleVstManufacturerSpecific (juce::int32 index,
+                                                           juce::pointer_sized_int value,
+                                                           void* ptr,
+                                                           float opt) override
     {
         juce::ignoreUnused (opt);
 
         //0x69656D is hex code for `iem` in ASCII
-        if (index == 0x0069656D)  // prefix 00 chooses OSC message
+        if (index == 0x0069656D) // prefix 00 chooses OSC message
         {
             try
             {
@@ -136,13 +130,15 @@ public:
         return 0;
     }
 
-    juce::pointer_sized_int handleVstPluginCanDo (juce::int32 index, juce::pointer_sized_int value,
-                                            void* ptr, float opt) override
+    juce::pointer_sized_int handleVstPluginCanDo (juce::int32 index,
+                                                  juce::pointer_sized_int value,
+                                                  void* ptr,
+                                                  float opt) override
     {
         juce::ignoreUnused (index, value, opt);
 
         auto text = (const char*) ptr;
-        auto matches = [=](const char* s) { return strcmp (text, s) == 0; };
+        auto matches = [=] (const char* s) { return strcmp (text, s) == 0; };
 
         if (matches ("wantsChannelCountNotifications"))
             return 1;
@@ -154,19 +150,14 @@ public:
     }
     //==============================================================================
 
-
-
-    OSCParameterInterface& getOSCParameterInterface () { return oscParameterInterface; }
+    OSCParameterInterface& getOSCParameterInterface() { return oscParameterInterface; }
 
     //==============================================================================
 
-
     juce::AudioProcessorValueTreeState parameters;
     OSCParameterInterface oscParameterInterface;
 
 private:
-
     bool shouldOpenNewPort = false;
     int newPortNumber = -1;
 };
-
